#!/usr/bin/env python
# 
#___INFO__MARK_BEGIN__ 
########################################################################## 
# Copyright 2016,2017 Univa Corporation
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0 
# 
# Unless required by applicable law or agreed to in writing, software 
# distributed under the License is distributed on an "AS IS" BASIS, 
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
# See the License for the specific language governing permissions and 
# limitations under the License. 
########################################################################### 
#___INFO__MARK_END__ 
# 

UGE_OK = 0
UGE_ERROR = 1
UGE_CONFIGURATION_ERROR = 2
UGE_AUTHORIZATION_ERROR = 3
UGE_COMMAND_FAILED = 4
UGE_INVALID_REQUEST = 5
UGE_INVALID_ARGUMENT = 6
UGE_QMASTER_UNREACHABLE = 7
UGE_OBJECT_NOT_FOUND = 8
UGE_OBJECT_ALREADY_EXISTS = 9

